@@ -60,6 +60,12 @@ install() {
 		# Fallback: Guess the path and include all matches
 		dracut_install /usr/lib*/gcc/**/libgcc_s.so*
 	fi
+	# shellcheck disable=SC2050
+	if [ 0 != 0 ]; then
+		for d in $libdirs; do
+			[ -e "$d/" ] && dracut_install "$d/"
+		done
+	fi
 	dracut_install /sbin/mount.zfs
 	dracut_install /lib/udev/vdev_id
 	dracut_install awk
